<?php
/*
* 2007-2015 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2015 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

if (!defined('_PS_VERSION_')) {
    exit;
}

class AirtelMoney extends PaymentModule
{
   /* protected $_html = '';
    protected $_postErrors = array();*/

    public $details;
    public $owner;
    public $address;
    public $extra_mail_vars;

    public function __construct()
    {
        $this->name = 'airtelmoney';
        $this->tab = 'payments_gateways';
        $this->version = '1.0.0';
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
        $this->author = 'BakoAi';
       // $this->controllers = array('validation');
       // $this->is_eu_compatible = 1;

       // $this->currencies = true;
       // $this->currencies_mode = 'checkbox';

        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->l('Airtel Money Payment');
        $this->description = $this->l('Airtel Money Online payment ');
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');


    }

    public function install()
    {
        if (!parent::install() ||
            !$this->registerHook('paymentOptions') ||
            !$this->registerHook('paymentReturn')) {
            return false;
        }else{
            Configuration::updateValue('AIRTELMONEY', $this->name);
            Configuration::updateValue('AIRTELMONEY_MERCHANT_PHONE',null);
            Configuration::updateValue('AIRTELMONEY_REF_PREFIX',"AM");
            Configuration::updateValue('AIRTELMONEY_DOMAIN_NAME',null);
        }
        return true;
    }

    public function uninstall()
    {


        if (!parent::uninstall() ||
            !Configuration::deleteByName('AIRTELMONEY') ||
            !Configuration::deleteByName('AIRTELMONEY_MERCHANT_PHONE') ||
            !Configuration::deleteByName('AIRTELMONEY_DOMAIN_NAME') ||
            !Configuration::deleteByName('AIRTELMONEY_REF_PREFIX') ||
            !$this->unregisterHook('paymentReturn') ||
            !$this->unregisterHook('paymentOptions')) {
            return false;
        }
        return true;
    }

    public function hookPaymentOptions($params)
    {
        if (!$this->active){
            return;
        }
        if (!$this->checkCurrency($params['cart'])) {
            return;
        }

//        $this->smarty->assign(
//            $this->getTemplateVars()
//        );
//
//        $newOption = new PaymentOption();
//        $newOption->setModuleName($this->name)
//            ->setCallToActionText($this->trans('Pay by Check', array(), 'Modules.Checkpayment.Admin'))
//            ->setAction($this->context->link->getModuleLink($this->name, 'validation', array(), true))
//            ->setAdditionalInformation($this->fetch('module:airtelmoney/views/templates/front/payment_infos.tpl'));
//
//        return [$newOption];



        $payment_options = [
            $this->getExternalPaymentOption()
        ];
        return $payment_options;
    }




    public function hookPaymentReturn($params)
    {

    }



    public function checkCurrency($cart)
    {
        $currency_order = new Currency($cart->id_currency);
        $currencies_module = $this->getCurrency($cart->id_currency);

        if (is_array($currencies_module)) {
            foreach ($currencies_module as $currency_module) {
                if ($currency_order->id == $currency_module['id_currency']) {
                    return true;
                }
            }
        }
        return false;
    }

    public function getExternalPaymentOption()
    {
        $id_cart = $this->context->cart->id;
        $customer = new Customer($this->context->cart->id_customer);
        $amount = $this->context->cart->getTotalCart($id_cart);
        $externalOption = new PaymentOption();
        $externalOption->setCallToActionText($this->l('Airtel Money Payment'))
                       //->setAction("https://mypvit.com/airtelmoneypvit.kk")
                       ->setAction($this->context->link->getModuleLink($this->name, 'payment', array("token"=>$this->context->customer->secure_key), true))
                       ->setInputs([
                            'tel_marchand' => [
                                'name' =>'tel_marchand',
                                'type' =>'hidden',
                                'value' =>Configuration::get('AIRTELMONEY_MERCHANT_PHONE')
                            ],

                            'montant' => [
                                'name' =>'montant',
                                'type' =>'hidden',
                                'value' =>$amount
                            ],

                            'redirect' => [
                                'name' =>'redirect',
                                'type' =>'hidden',
                                'value' =>$this->context->link->getBaseLink()."index.php?controller=order-confirmation&id_cart=".$id_cart."&id_module=".$this->id."&id_order=".$this->currentOrder."&key=".$customer->secure_key
                            ]
                        ])
                       ->setLogo(Media::getMediaPath(_PS_MODULE_DIR_.$this->name.'/logo.png'));


        return $externalOption;
    }


    public function getContent()
    {
        $output = null;
        $regex = '/^0[0-9]{5,9}\b/i';

        if (Tools::isSubmit('submit'.$this->name)) {
            $myModuleName = strval(Tools::getValue('airtelmoney'));
            $merchantPhone = strval(Tools::getValue('merchant_phone'));
            $domaine = strval(Tools::getValue('domaine_name'));
            $prefix = strval(Tools::getValue('prefix'));

            if (!$myModuleName  || !$merchantPhone  ||
                empty($myModuleName) || empty($merchantPhone) ||
                !Validate::isGenericName($myModuleName) || !Validate::isGenericName($merchantPhone) ) {
                $output .= $this->displayError($this->l('At least one value is incorrect'));
            } else {
                if(preg_match($regex,$merchantPhone) == 1){
                    if(trim($prefix) == '')
                        $prefix = "AM";
                    Configuration::updateValue('AIRTELMONEY', $myModuleName);
                    Configuration::updateValue('AIRTELMONEY_MERCHANT_PHONE', $merchantPhone);
                    Configuration::updateValue('AIRTELMONEY_REF_PREFIX', $prefix);
                    Configuration::updateValue('AIRTELMONEY_DOMAIN_NAME', $domaine);

                    $output .= $this->displayConfirmation($this->l('Settings updated'));
                }else{
                    $output .= $this->displayError($this->l('Incorrect phone number'));
                }
            }
        }

        return $output.$this->displayForm();
    }


    public function displayForm()
    {
        // Get default language
        $defaultLang = (int)Configuration::get('PS_LANG_DEFAULT');

        // Init Fields form array
        $fieldsForm[0]['form'] = [
            'legend' => [
                'title' => $this->l('Settings'),
            ],
            'input' => [
                [
                    'type' => 'text',
                    'label' => $this->l('Module name'),
                    'name' => 'airtelmoney',
                    'required' => true
                ],
                [
                    'type' => 'text',
                    'label' => $this->l('Airtel Money merchant phone number (without country code)'),
                    'name' => 'merchant_phone',
                    'size' => 11,
                    'required' => true
                ],
                [
                    'type' => 'text',
                    'label' => $this->l('Prefixe de reference'),
                    'name' => 'prefix',
                    'size' => 3
                ],
                [
                    'type' => 'text',
                    'label' => $this->l('Domaine name or web site adresse'),
                    'name' => 'domaine_name',
                    'size' => 255
                ]

            ],
            'submit' => [
                'title' => $this->l('Save'),
                'class' => 'btn btn-default pull-right'
            ]
        ];

        $helper = new HelperForm();

        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;

        // Language
        $helper->default_form_language = $defaultLang;
        $helper->allow_employee_form_lang = $defaultLang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = true;        // false -> remove toolbar
        $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
        $helper->submit_action = 'submit'.$this->name;
        $helper->toolbar_btn = [
            'save' => [
                'desc' => $this->l('Save'),
                'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.
                    '&token='.Tools::getAdminTokenLite('AdminModules'),
            ],
            'back' => [
                'href' => AdminController::$currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            ]
        ];

        // Load current value

        $helper->fields_value['airtelmoney'] = Configuration::get('AIRTELMONEY');
        $helper->fields_value['merchant_phone'] = Configuration::get('AIRTELMONEY_MERCHANT_PHONE');
        $helper->fields_value['prefix'] = Configuration::get('AIRTELMONEY_REF_PREFIX');
        $helper->fields_value['domaine_name'] = Configuration::get('AIRTELMONEY_DOMAIN_NAME');


        return $helper->generateForm($fieldsForm);
    }

    public function  getTemplateVars(){
        
    }

}